@@ -1,7 +1,7 @@
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.0 Apophis
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: cutoff.c,v 1.3 2003/11/26 20:18:46 alec Exp $
+ *  $Id: cutoff.c,v 1.6 2004/02/18 12:49:22 lukasz Exp $
  */
 #include <stdio.h>
 #include <syslog.h>
@@ -53,8 +53,8 @@ void reload(GLOBAL *g, struct cutoff_module *c)
 		// set timestamps
 		if( exec ) {
 			g->db_exec("DELETE FROM timestamps WHERE tablename = 'nodes' OR tablename = '_global'");
-			g->db_exec("INSERT INTO timestamps (tablename,time) VALUES ('nodes',?NOW?)");
-			g->db_exec("INSERT INTO timestamps (tablename,time) VALUES ('_global',?NOW?)");
+			g->db_exec("INSERT INTO timestamps (tablename,time) VALUES ('nodes',%NOW%)");
+			g->db_exec("INSERT INTO timestamps (tablename,time) VALUES ('_global',%NOW%)");
 		}	
 #ifdef DEBUG1
 		syslog(LOG_INFO, "DEBUG: [%s/cutoff] reloaded", c->base.instance);
