@@ -1,7 +1,7 @@
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.0 Apophis
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: dhcp.c,v 1.8 2003/11/27 20:43:48 alec Exp $
+ *  $Id: dhcp.c,v 1.11 2004/02/18 12:49:22 lukasz Exp $
  */
 
 #include <stdio.h>
@@ -69,7 +69,7 @@ void reload(GLOBAL *g, struct dhcp_module *dhcp)
 		}
 		fprintf(fh, "%s\n", dhcp->prefix);
 		
-		if( (res = g->db_query("SELECT address, mask, gateway, dns, dns2, domain, wins, dhcpstart, dhcpend FROM networks"))!=NULL ) {
+		if( (res = g->db_query("SELECT inet_ntoa(address) AS address, mask, gateway, dns, dns2, domain, wins, dhcpstart, dhcpend FROM networks"))!=NULL ) {
 
 			for(i=0; i<res->nrows; i++) {
 			
