@@ -1,7 +1,7 @@
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.0 Apophis
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: dns.c,v 1.4 2003/11/12 20:15:10 alec Exp $
+ *  $Id: dns.c,v 1.7 2004/02/18 12:49:22 lukasz Exp $
  */
 
 #include <stdio.h>
@@ -123,7 +123,7 @@ void reload(GLOBAL *g, struct dns_module *dns)
 		g->db_free(res);
 	}
 	
-	if ( (res = g->db_query("SELECT address, mask, domain, dns FROM networks"))!=NULL) {
+	if ( (res = g->db_query("SELECT inet_ntoa(address) AS address, mask, domain, dns FROM networks"))!=NULL) {
 
 		configfile = load_file(dns->confpattern);
 	
