@@ -1,7 +1,7 @@
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.0 Apophis
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -19,7 +19,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: traffic.c,v 1.1 2003/11/18 20:36:53 alec Exp $
+ *  $Id: traffic.c,v 1.4 2004/02/18 12:49:22 lukasz Exp $
  */
 #include <stdio.h>
 #include <syslog.h>
@@ -86,7 +86,7 @@ void reload(GLOBAL *g, struct traffic_module *traffic)
 					
 					if( atoi(download) || atoi(upload) ) { // write not null data
 					
-						insert = strdup("INSERT INTO stats (nodeid, dt, download, upload) VALUES (%nodeid, ?NOW?, %download, %upload)"); 
+						insert = strdup("INSERT INTO stats (nodeid, dt, download, upload) VALUES (%nodeid, %NOW%, %download, %upload)"); 
 						g->str_replace(&insert, "%nodeid", itoa(k));
 						g->str_replace(&insert, "%download", download);
 						g->str_replace(&insert, "%upload", upload);
