@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.0 Apophis
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: LMSDB_driver_mysql.class.php,v 1.17 2003/09/12 22:34:21 alec Exp $
+ *  $Id: LMSDB_driver_mysql.class.php,v 1.21 2004/02/18 12:49:23 lukasz Exp $
  */
 
 /*
@@ -35,9 +35,14 @@ class LMSDB_driver_mysql extends LMSDB_common
 
 	function LMSDB_driver_mysql($dbhost,$dbuser,$dbpasswd,$dbname)
 	{
-		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.17 $').')';
+		$this->_version .= ' (core: '.eregi_replace('^.Revision: ([0-9.]+).*','\1',$this->_revision).' / driver: '.$this->_dbtype.' '.eregi_replace('^.Revision: ([0-9.]+).*','\1','$Revision: 1.21 $').')';
 		$this->Connect($dbhost,$dbuser,$dbpasswd,$dbname);
 	}
+	
+	function _driver_dbversion()
+	{
+		return mysql_get_server_info();
+	}
 
 	function _driver_connect($dbhost,$dbuser,$dbpasswd,$dbname)
 	{
@@ -132,47 +137,4 @@ class LMSDB_driver_mysql extends LMSDB_common
 	}
 }
 
-/* 
- * $Log: LMSDB_driver_mysql.class.php,v $
- * Revision 1.17  2003/09/12 22:34:21  alec
- * bug fix (I think so)
- *
- * Revision 1.16  2003/09/12 22:22:52  alec
- * Execute zwraca ilo zmodyfikowanych wierszy dla zapyta UPDATE, DELETE, INSERT
- *
- * Revision 1.15  2003/09/10 00:16:19  lukasz
- * - LMSDB::Destroy();
- *
- * Revision 1.14  2003/08/31 03:34:20  lukasz
- * - maa literwka powodujca to i driver od MySQL'a nie dostawa informacji
- *   o hocie z lms.ini, a co za tym idzie zawsze czy si z localhostem.
- *
- * Revision 1.13  2003/08/28 21:07:26  lukasz
- * - added support for transactions
- *
- * Revision 1.12  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.11  2003/08/24 00:37:07  lukasz
- * *** empty log message ***
- *
- * Revision 1.10  2003/08/22 13:15:27  lukasz
- * - ListTables()
- *
- * Revision 1.9  2003/08/19 00:58:43  lukasz
- * - fixed usage of mysql_error();
- *
- * Revision 1.8  2003/08/18 17:16:25  lukasz
- * - temporary save
- *
- * Revision 1.7  2003/08/18 16:47:37  lukasz
- * - once again fixed CVS tags
- *
- * Revision 1.6  2003/08/18 16:46:50  lukasz
- * - fixed CVS tags
- * - beta state - need testing
- *
- */
-
 ?>
