@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.0 Apophis
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: Sysinfo.class.php,v 1.9 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: Sysinfo.class.php,v 1.13 2004/02/18 12:49:23 lukasz Exp $
  */
 
 /*
@@ -101,12 +101,12 @@ class Sysinfo {
 		switch(PHP_OS)
 		{
 			case "Linux":
-			case "FreeBSD":
-			case "OpenBSD":
-			case "NetBSD":
 				exec("hostname -f",$return);
 				$hostname=$return[0];
 				break;
+			case "FreeBSD":
+			case "OpenBSD":
+			case "NetBSD":
 			case "WinNT":
 				exec("hostname",$return);
 				$hostname=$return[0];
@@ -249,6 +249,14 @@ class Sysinfo {
 				else
 					$results = array('N.A.','N.A.','N.A.');
 			break;
+			case "FreeBSD":
+			case "NetBSD":
+			case "OpenBSD":			
+				$s = $this->bsd_grab_key('vm.loadavg');
+				$s = ereg_replace('{ ', '', $s);
+				$s = ereg_replace(' }', '', $s);
+				$results = explode(' ', $s);
+			break;
 			default:
 				$results = array('N.A.','N.A.','N.A.');
 			break;
@@ -258,15 +266,4 @@ class Sysinfo {
 											    
 }
 
-/*
- * $Log: Sysinfo.class.php,v $
- * Revision 1.9  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.8  2003/08/18 16:57:00  lukasz
- * - more cvs tags :>
- *
- */
-
 ?>
