@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.0 Apophis
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: accesstable.php,v 1.14 2003/09/11 17:29:30 lexx Exp $
+ *  $Id: accesstable.php,v 1.21 2004/02/18 12:49:23 lukasz Exp $
  */
 
 // lista moduw ktre zawsze s dostpne dla kadego
@@ -32,13 +32,13 @@ $access[table][0][name]		= "peen dostp";
 $access[table][0][allow_reg]	= "^.*$";
 
 $access[table][1][name]		= "odczyt wszystkich danych";
-$access[table][1][allow_reg]	= "^((admin|balance|db|net|node|tariff|user)(list|list(debt|disc)|info|view|debt|search|balance)|print)$";
+$access[table][1][allow_reg]	= "^((admin|balance|db|net|node|netdev|tariff|payment|user)(list|list(debt|disc)|info|view|debt|search|balance)|netdevmap|print)$";
 
 $access[table][2][name]		= "wczanie i odczanie komputerw";
 $access[table][2][allow_reg]	= "^nodeset$";
 
 $access[table][3][name]		= "manipulacja finansami";
-$access[table][3][allow_reg]	= "^(balancenew|balanceadd|userbalanceok|faktura)$";
+$access[table][3][allow_reg]	= "^((tariff)(add|info|list|move|edit|delete)|(payment)(add|del|edit|info|list)|(balance|balance|userbalance)(new|add|ok)|(invoice|invoice(list|new)))$";
 
 $access[table][4][name]         = "przeadowywanie konfiguracji";
 $access[table][4][allow_reg]    = "^reload$";
@@ -52,27 +52,13 @@ $access[table][6][allow_reg]	= "^(node(add|scan|del|edit|set)|choose(mac|ip))$";
 $access[table][7][name]         = "dostp do statystyk";
 $access[table][7][allow_reg]    = "^traffic$";
 
+$access[table][8][name]         = "dostp do korespondencji seryjnej";
+$access[table][8][allow_reg]    = "^(mailing|mailingsend)$";
+
 $access[table][253][name]	= "brak dostpu do modyfikacji i zakadania nowych kont administratorw";
 $access[table][253][deny_reg]	= "^(admin(add|del|edit|passwd))$";
 
 $access[table][255][name]	= "brak dostpu";
 $access[table][255][deny_reg]	= "^.*$";
 
-/*
- * $Log: accesstable.php,v $
- * Revision 1.14  2003/09/11 17:29:30  lexx
- * - taffic
- *
- * Revision 1.13  2003/09/10 13:38:34  lexx
- * - faktury
- *
- * Revision 1.12  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.11  2003/08/18 16:57:00  lukasz
- * - more cvs tags :>
- *
- */
-
 ?>
