@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.0 Apophis
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,11 +21,13 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: balancelist.php,v 1.24 2003/12/04 04:39:14 lukasz Exp $
+ *  $Id: balancelist.php,v 1.28 2004/02/18 12:49:23 lukasz Exp $
  */
 
 $_SESSION['backto'] = $_SERVER['QUERY_STRING'];
+
 $balancelist = $LMS->GetBalanceList();
+
 $listdata['incomeu'] = $balancelist['incomeu'];
 $listdata['income'] = $balancelist['income'];
 $listdata['uinvoice'] = $balancelist['uinvoice'];
@@ -37,13 +39,11 @@ unset($balancelist['uinvoice']);
 unset($balancelist['expense']);
 unset($balancelist['total']);
 $listdata['totalpos'] = sizeof($balancelist);
-if (isset($_SESSION['blp']) && !isset($_GET['page']))
-        $_GET['page'] = $_SESSION['blp'];
-	
+
 $pagelimit = $LMS->CONFIG['phpui']['balancelist_pagelimit'];
 $page = (! $_GET['page'] ? ceil($listdata['totalpos']/$pagelimit) : $_GET['page']); 
 $start = ($page - 1) * $pagelimit;
-$_SESSION['blp'] = $page;
+
 $layout['pagetitle'] = "Bilans finansowy";
 $SMARTY->assign("layout",$layout);
 
@@ -57,21 +57,4 @@ $SMARTY->assign("pagelimit",$pagelimit);
 $SMARTY->assign("start",$start);
 $SMARTY->display("balancelist.html");
 
-/*
- * $Log: balancelist.php,v $
- * Revision 1.24  2003/12/04 04:39:14  lukasz
- * - porzdki
- * - troch podubane przy parsowaniu pliku konfiguracyjnego
- *
- * Revision 1.23  2003/08/25 02:11:58  lukasz
- * - changed default pagelimit from 50 to 100
- *
- * Revision 1.22  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.21  2003/08/18 16:52:19  lukasz
- * - added CVS Log tags
- *
- */
 ?>
