@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.0 Apophis
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: dbdel.php,v 1.15 2003/08/24 13:12:54 lukasz Exp $
+ *  $Id: dbdel.php,v 1.18 2004/02/18 12:49:23 lukasz Exp $
  */
 
 if($_GET[is_sure])
@@ -29,7 +29,8 @@ if($_GET[is_sure])
 	$LMS->DatabaseDelete($_GET[db]);
 	header("Location: ?m=".$_SESSION[lastmodule]);
 	die;
-}else{
+} else
+{
 	$layout[pagetitle]="Usunicie bazy danych";
 	$SMARTY->assign("layout",$layout);
 	$SMARTY->display("header.html");
@@ -38,14 +39,5 @@ if($_GET[is_sure])
 	echo "<a href=\"?m=dbdel&db=".$_GET[db]."&is_sure=1\">Tak, jestem pewien</A>";
 	$SMARTY->display("footer.html");
 }
-/*
- * $Log: dbdel.php,v $
- * Revision 1.15  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.14  2003/08/18 16:52:19  lukasz
- * - added CVS Log tags
- *
- */
+
 ?>
\ No newline at end of file
