@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.0 Apophis
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,36 +21,33 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoice.php,v 1.13 2003/12/04 22:41:54 lukasz Exp $
+ *  $Id: invoice.php,v 1.21 2004/02/18 12:49:23 lukasz Exp $
  */
-
 header('Content-Type: '.$LMS->CONFIG['invoices']['content_type']);
 if($LMS->CONFIG['invoices']['attachment_name'] != '')
 	header('Content-Disposition: attachment; filename='.$LMS->CONFIG['invoices']['attachment_name']);
-				
 
-if($_GET['print'] == 'cached' && sizeof($_SESSION['ilp_marks']))
+if($_GET['print'] == 'cached' && sizeof($_POST['marks']))
 {
 	$layout['pagetitle'] = 'Faktury VAT';
 	$SMARTY->assign('layout',$layout);
 	$SMARTY->display('clearheader.html');
-	foreach($_SESSION['ilp_marks'] as $markid => $junk)
+	foreach($_POST['marks'] as $markid => $junk)
 		if($junk)
 			$ids[] = $markid;
 	sort($ids);
+	$which = ($_GET[which] != '' ? $_GET[which] : 'ORYGINA+KOPIA');
 	foreach($ids as $idx => $invoiceid)
 	{
+		echo '<PRE>';
 		$invoice = $LMS->GetInvoiceContent($invoiceid);
-		$SMARTY->assign('type','ORYGINA');
-		$SMARTY->assign('invoice',$invoice);
-		$SMARTY->display($LMS->CONFIG['invoices']['template_file']);
-		$SMARTY->assign('type','KOPIA');
-		if(! $ids[$idx+1])
+		foreach(split('\+', $which) as $type)
 		{
-			$invoice['last'] = TRUE;
+			$SMARTY->assign('type',$type);
+
 			$SMARTY->assign('invoice',$invoice);
+			$SMARTY->display($LMS->CONFIG['invoices']['template_file']);
 		}
-		$SMARTY->display($LMS->CONFIG['invoices']['template_file']);
 	}
 	$SMARTY->display('clearfooter.html');
 }
@@ -77,4 +74,5 @@ else
 	header('Location: ?m=invoicelist');
 	die;
 }
+
 ?>
