@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.0 Apophis
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,22 +21,16 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: invoicelist.php,v 1.4 2003/12/04 04:39:14 lukasz Exp $
+ *  $Id: invoicelist.php,v 1.11 2004/02/18 12:49:23 lukasz Exp $
  */
 
 $layout['pagetitle'] = 'Lista faktur';
 
-if($_GET['action'] == 'updatemarks')
-{
-	if(sizeof($_POST['mark']))
-		foreach($_POST['mark'] as $markid => $mark)
-			if($_SESSION['ilp_marks'][$markid])
-				unset($_SESSION['ilp_marks'][$markid]);
-			else
-				$_SESSION['ilp_marks'][$markid] = TRUE;
-}
-elseif($_GET['action'] == 'clearmarks')
-	unset($_SESSION['ilp_marks']);
+$marks = $_POST['marks'];
+unset($marked);
+if( sizeof($marks) )
+	foreach($marks as $marksid => $mark)
+		$marked[] = $mark;
 
 $invoicelist = $LMS->GetInvoicesList();
 
@@ -49,15 +43,9 @@ unset($invoicelist['startdate'], $invoicelist['enddate']);
 
 $listdata['totalpos'] = sizeof($invoicelist);
 
-if (isset($_SESSION['blp']) && !isset($_GET['page']))
-	$_GET['page'] = $_SESSION['ilp'];
-
 $pagelimit = $LMS->CONFIG['phpui']['invoicelist_pagelimit'];
 $page = (! $_GET['page'] ? ceil($listdata['totalpos']/$pagelimit) : $_GET['page']);
 $start = ($page - 1) * $pagelimit;
-$_SESSION['ilp'] = $page;
-
-$marks = $_SESSION['ilp_marks'];
 
 $SMARTY->assign('listdata',$listdata);
 $SMARTY->assign('pagelimit',$pagelimit);
@@ -65,7 +53,9 @@ $SMARTY->assign('start',$start);
 $SMARTY->assign('page',$page);
 $SMARTY->assign('layout',$layout);
 $SMARTY->assign('marks',$marks);
+$SMARTY->assign('marked',$marked);
 $SMARTY->assign('invoicelist',$invoicelist);
+$SMARTY->assign('openonload',$_GET['openonload']);
 $SMARTY->display('invoicelist.html');
 
 ?>
