@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.0 Apophis
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,25 +21,12 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: mailing.php,v 1.16 2003/09/05 13:11:23 lukasz Exp $
+ *  $Id: mailing.php,v 1.20 2004/02/18 12:49:23 lukasz Exp $
  */
 
 $layout[pagetitle]="Mailing";
+
 $SMARTY->assign("layout",$layout);
-$SMARTY->display("header.html");
 $SMARTY->display("mailing.html");
-$SMARTY->display("footer.html");
-/*
- * $Log: mailing.php,v $
- * Revision 1.16  2003/09/05 13:11:23  lukasz
- * - nowy sposb wywietlania informacji o bdach
- *
- * Revision 1.15  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.14  2003/08/18 16:52:19  lukasz
- * - added CVS Log tags
- *
- */
+
 ?>
