@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.0 Apophis
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: netdevmap.php,v 1.9 2003/10/22 23:07:52 lukasz Exp $
+ *  $Id: netdevmap.php,v 1.13 2004/02/18 12:49:23 lukasz Exp $
 
                                  _
  _   ___      ____ _  __ _  __ _| |
@@ -113,7 +113,7 @@ function makemap(&$DB, &$map, &$seen, $device = 0, $x = 50, $y = 50)
 			}				
 		}
 
-		if($nodes = $DB->GetCol("SELECT id FROM nodes WHERE netdev=? ORDER BY name ASC",array($device)))
+		if($nodes = $DB->GetCol("SELECT id FROM nodes WHERE netdev=? AND ownerid>0 ORDER BY name ASC",array($device)))
 		{
 			foreach($nodes as $nodeid)
 			{
@@ -238,8 +238,8 @@ else
 		imageline($im, $src_px+4, $src_py+4, $dst_px+4, $dst_py+4, $red);
 	}
 
-	$im_nd = imagecreatefromgif('img/netdev.gif');
-	$im_n = imagecreatefromgif('img/node.gif');
+	$im_nd = imagecreatefrompng('img/netdev.png');
+	$im_n = imagecreatefrompng('img/node.png');
 
 //	print_r($nodemap);
 	
