@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.0 Apophis
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,19 +21,12 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: nodeadd.php,v 1.38 2003/12/04 04:39:14 lukasz Exp $
+ *  $Id: nodeadd.php,v 1.43 2004/02/18 12:49:23 lukasz Exp $
  */
 
-if($LMS->UserExists($_GET[ownerid]) < 0)
-{
-	header('Location: ?m=userinfo&id='.$_GET[ownerid]);
-	die;
-}
 
 $nodedata = $_POST[nodedata];
 
-$users = $LMS->GetUserNames();
-
 if(isset($nodedata))
 {
 	$nodedata[ipaddr] = $_POST[nodedataipaddr];
@@ -60,7 +53,7 @@ if(isset($nodedata))
 	elseif($LMS->GetNodeIDByName($nodedata[name]))
 		$error[name] = "Podana nazwa jest uywana!";
 	elseif(!eregi("^[_a-z0-9-]+$",$nodedata[name]))
-		$error[name] = "Podana nazwa zawiera niepoprawne znaki";		
+		$error[name] = "Podana nazwa zawiera niepoprawne znaki!";		
 
 	if(!$nodedata[ipaddr])
 		$error[ipaddr] = "Prosz podac adres IP!";
@@ -71,7 +64,9 @@ if(isset($nodedata))
 	elseif(!$LMS->IsIPFree($nodedata[ipaddr]))
 		$error[ipaddr] = "Podany adres IP jest zajty!";
 
-	if($LMS->GetNodeIDByMAC($nodedata[mac]) && $LMS->CONFIG[phpui][allow_mac_sharing] == FALSE)
+	if(!$nodedata[mac])
+		$error[mac] = "Prosz podac adres MAC!";
+	elseif($LMS->GetNodeIDByMAC($nodedata[mac]) && $LMS->CONFIG[phpui][allow_mac_sharing] == FALSE)
 		$error[mac] = "Podany MAC jest ju w bazie!";
 	elseif(!check_mac($nodedata[mac]))
 		$error[mac] = "Podany adres MAC jest nieprawidowy!";
@@ -85,10 +80,21 @@ if(isset($nodedata))
 	if(!$error)
 	{
 		$nodeid=$LMS->NodeAdd($nodedata);
-		header("Location: ?m=nodeinfo&id=".$nodeid);
-		die;
+		if($nodedata['reuse']=='')
+		{
+			header("Location: ?m=nodeinfo&id=".$nodeid);
+			die;
+		}
+		unset($nodedata);
+		$nodedata['reuse'] = '1';
 	}
-		
+
+}
+
+if($LMS->UserExists($_GET[ownerid]) < 0)
+{
+	header('Location: ?m=userinfo&id='.$_GET[ownerid]);
+	die;
 }
 
 $nodedata[access] = 1;
@@ -114,6 +120,7 @@ $layout[pagetitle]="Nowy komputer";
 $tariffs = $LMS->GetTariffs();
 $balancelist = $LMS->GetUserBalanceList($nodedata[ownerid]);
 $assignments = $LMS->GetUserAssignments($nodedata[ownerid]);
+$users = $LMS->GetUserNames();
 
 $SMARTY->assign("balancelist",$balancelist);
 $SMARTY->assign("assignments",$assignments);
@@ -126,36 +133,5 @@ $SMARTY->assign("layout",$layout);
 
 $SMARTY->display("nodeadd.html");
 
-/*
- * $Log: nodeadd.php,v $
- * Revision 1.38  2003/12/04 04:39:14  lukasz
- * - porzdki
- * - troch podubane przy parsowaniu pliku konfiguracyjnego
- *
- * Revision 1.37  2003/10/07 19:15:05  alec
- * ujednolicenie naglowka
- *
- * Revision 1.36  2003/09/12 02:52:57  lukasz
- * - cosmetics
- *
- * Revision 1.35  2003/09/09 01:44:07  lukasz
- * - poprawki node{edit,info,add}
- *
- * Revision 1.34  2003/09/01 12:34:05  lukasz
- * - BTS #0000066
- *
- * Revision 1.33  2003/08/27 19:26:15  lukasz
- * - changed format of ipaddr storage in database
- *
- * Revision 1.32  2003/08/25 02:12:13  lukasz
- * - zmieniona obsuga usuwania userw
- *
- * Revision 1.31  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.30  2003/08/18 16:52:19  lukasz
- * - added CVS Log tags
- *
- */
 ?>
+
