@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.0 Apophis
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: tariffedit.php,v 1.15 2003/12/01 02:12:48 lukasz Exp $
+ *  $Id: tariffedit.php,v 1.19 2004/02/18 12:49:23 lukasz Exp $
  */
 
 if(!$LMS->TariffExists($_GET['id']))
@@ -52,7 +52,7 @@ if(isset($tariff))
 
 	if($tariff['value'] == "")
 		$error['value'] = "Prosz poda warto!";
-	elseif(!(ereg("^[0-9.,]+$", $tariff['value'])))
+	elseif(!(ereg("^[-]?[0-9.,]+$", $tariff['value'])))
 		$error['value'] = "Podana warto jest niepoprawna!";
 	
 	if($tariff['taxvalue'] == "")
@@ -90,20 +90,5 @@ $SMARTY->assign("layout",$layout);
 $SMARTY->assign("tariff",$tariff);
 $SMARTY->assign("error",$error);
 $SMARTY->display("tariffedit.html");
-/*
- * $Log: tariffedit.php,v $
- * Revision 1.15  2003/12/01 02:12:48  lukasz
- * - tsave - do nowych faktur... jak si wypi to dokocz
- *
- * Revision 1.14  2003/10/03 16:02:45  alec
- * ujednolicenie interfejsu
- *
- * Revision 1.13  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.12  2003/08/18 16:52:19  lukasz
- * - added CVS Log tags
- *
- */
+
 ?>
