@@ -1,8 +1,9 @@
-<?
+<?php
+
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.0 Apophis
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -20,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: trafficdbcompact.php,v 1.2 2003/10/08 15:44:52 alec Exp $
+ *  $Id: trafficdbcompact.php,v 1.5 2004/02/18 12:49:23 lukasz Exp $
  */
 
 $delete = $_POST['delete'];
