@@ -1,9 +1,9 @@
-<?
+<?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.0 Apophis
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: upgrade01.php,v 1.2 2003/09/09 20:23:00 lukasz Exp $
+ *  $Id: upgrade01.php,v 1.6 2004/02/18 12:49:23 lukasz Exp $
  */
 
 $SMARTY->display('header.html');
@@ -34,6 +34,8 @@ foreach($users as $idx => $row)
 {
 	echo $row[lastname]." ".$row[name].": ";
 	echo "taryfa: '".$tariffs[$row[tariff]][name]."'... ";
-	$LMS->AddAssignment(array('tariffid' => $row[tariff], 'at' => $row[payday], 'userid' => $row[id], 'period' => 0));
+	$LMS->AddAssignment(array('tariffid' => $row[tariff], 'at' => $row[payday], 'userid' => $row[id], 'period' => 0, 'invoice' => 0));
 	echo "ok.\n";
 }
+
+?>
\ No newline at end of file
