@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.0 Apophis
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,7 +21,7 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: userbalance.php,v 1.19 2003/10/06 22:02:09 lukasz Exp $
+ *  $Id: userbalance.php,v 1.23 2004/02/18 12:49:23 lukasz Exp $
  */
 
 if(!$LMS->UserExists($_GET[id]))
@@ -30,7 +30,7 @@ if(!$LMS->UserExists($_GET[id]))
 $username=$LMS->GetUserName($_GET[id]);
 $id = $_GET[id];
 
-$layout[pagetitle]='Rachunek uytkownika <A HREF="?m=userinfo&id='.$_GET[id].'">'.$username.'</A>';
+$layout[pagetitle]='Rachunek uytkownika: <A HREF="?m=userinfo&id='.$_GET[id].'">'.$username.'</A>';
 
 $SMARTY->assign("balancelist",$LMS->GetUserBalanceList($_GET[id]));
 $SMARTY->assign("layout",$layout);
@@ -38,26 +38,4 @@ $SMARTY->assign("username",$username);
 $SMARTY->assign("id",$id);
 $SMARTY->display("userbalance.html");
 
-/*
- * $Log: userbalance.php,v $
- * Revision 1.19  2003/10/06 22:02:09  lukasz
- * - ju nie psuje
- *
- * Revision 1.18  2003/10/06 18:53:22  lexx
- * - odsyacz psu tytu strony
- *
- * Revision 1.17  2003/09/09 01:22:28  lukasz
- * - nowe finanse
- * - kosmetyka
- * - bugfixy
- * - i inne rzeczy o ktrych aktualnie nie pamitam
- *
- * Revision 1.16  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.15  2003/08/18 16:52:19  lukasz
- * - added CVS Log tags
- *
- */
 ?>
