@@ -1,9 +1,9 @@
 <?php
 
 /*
- * LMS version 1.1.5 Amaonet
+ * LMS version 1.3.0 Apophis
  *
- *  (C) Copyright 2001-2003 LMS Developers
+ *  (C) Copyright 2001-2004 LMS Developers
  *
  *  Please, see the doc/AUTHORS for more information about authors!
  *
@@ -21,36 +21,23 @@
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
  *  USA.
  *
- *  $Id: welcome.php,v 1.27 2003/09/24 22:33:54 lukasz Exp $
+ *  $Id: welcome.php,v 1.32 2004/02/18 12:49:24 lukasz Exp $
  */
+
 require_once($_LIB_DIR."/Sysinfo.class.php");
 require_once($_LIB_DIR."/fortunes.php");
 
 $SI = new Sysinfo;
 
-$layout[pagetitle]="Witamy w LMS :-) !";
+$layout['pagetitle'] = "LAN Management System";
+
+$layout['dbversion'] = $LMS->DB->GetDBVersion();
+$layout['dbtype'] = $LMS->CONFIG['database']['type'];
+
 $SMARTY->assign("sysinfo",$SI->get_sysinfo());
 $SMARTY->assign("userstats",$LMS->UserStats());
 $SMARTY->assign("nodestats",$LMS->NodeStats());
 $SMARTY->assign("layout",$layout);
 $SMARTY->display("welcome.html");
-/*
- * $Log: welcome.php,v $
- * Revision 1.27  2003/09/24 22:33:54  lukasz
- * - s/TipOfTheDay/fortunes/g
- *
- * Revision 1.26  2003/08/28 11:36:47  lukasz
- * - http://bts.rulez.pl/bug_view_page.php?bug_id=0000057
- *
- * Revision 1.25  2003/08/24 13:12:54  lukasz
- * - massive attack: s/<?/<?php/g - that was causing problems on some fucked
- *   redhat's :>
- *
- * Revision 1.24  2003/08/18 16:57:00  lukasz
- * - more cvs tags :>
- *
- * Revision 1.23  2003/08/18 16:52:19  lukasz
- * - added CVS Log tags
- *
- */
+
 ?>
